//#define XERR
#include "mri.ih"

VSDvect const *MRI::vDose() const
{
    return 0;
}
